==> nextcloud-21.0.0-9-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/vi.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Đang nạp để xem trước",
    "Saved" : "Đã lưu",
    "Admin" : "Quản trị hệ thống",
    "a safe home for all your data" : "Một ngôi nhà an toàn cho toàn bộ dữ liệu của bạn",
    "Name cannot be empty" : "Tên không thể bị bỏ trống",
    "The given name is too long" : "Tên quá dài",
    "The given web address is too long" : "Địa chỉ web quá dài",
    "The given web address is not a valid URL" : "Địa chỉ web được cấp không phải là một đường dân URL khả dụng",
    "The given legal notice address is too long" : "Địa chỉ thông cáo pháp lý được cấp quá dài",
    "The given legal notice address is not a valid URL" : "Địa chỉ thông cáo pháp lý được cấp không phải là một đường dẫn URL khả dụng",
    "The given privacy policy address is too long" : "Địa chỉ chính sách riêng tư quá dài",
    "The given privacy policy address is not a valid URL" : "Địa chỉ chính sách riêng tư được cấp không phải là một đường dẫn URL khả dụng",
    "The given slogan is too long" : "Khẩu hiệu quá dài",
    "The given color is invalid" : "Màu đã chọn không hợp lệ",
    "The file was uploaded" : "Tập tin đã được tải lên",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tập tin tải lên đã vượt quá upload_max_filesize giới hạn trong hệ thống",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tập được tải lên vượt quá MAX_FILE_SIZE đã được giới hạn trong biểu mẫu HTML",
    "The file was only partially uploaded" : "Tệp chỉ được tải lên một phần",
    "No file was uploaded" : "Chưa có tệp nào dược tải lên",
    "Missing a temporary folder" : "Thiếu một thư mục tạm thời",
    "Could not write file to disk" : "Không thể ghi tệp lên hệ thống",
    "A PHP extension stopped the file upload" : "Một chức năng mở rộng của PHP đã dừng tải tệp lên",
    "No file uploaded" : "Không có tệp nào được tải lên",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Bạn đang sử dụng 1 chủ đề riêng. Các thiết lập của ứng dụng Chủ đề có thể bị ghi đè bởi nó.",
    "Theming" : "Điều chỉnh giao diện",
    "Legal notice" : "Thông cáo pháp lý",
    "Privacy policy" : "Chính sách riêng tư",
    "Adjust the Nextcloud theme" : "Tinh chỉnh chủ đề Nextcloud",
    "Open documentation" : "Mở tài liệu",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Điều chỉnh giao diện cho phép bạn có thể dễ dàng tùy biến bố cục trình bày của hệ thống. Khi thực hiện nó sẽ hiện hữu đối với tất cả người dùng",
    "Name" : "Tên",
    "Reset to default" : "Đặt lại về mặc định",
    "Web link" : "Liên kết web",
    "https://…" : "https://…",
    "Slogan" : "Khẩu hiệu",
    "Color" : "Màu sắc",
    "Logo" : "Logo",
    "Upload new logo" : "Tải lên logo mới",
    "Login image" : "Hình ảnh trang đăng nhập",
    "Upload new login background" : "Tải lên ảnh nền trang đăng nhập mới",
    "Remove background image" : "Xóa bỏ ảnh nền",
    "Advanced options" : "Tùy chọn nâng cao",
    "Legal notice link" : "Liên kết Thông cáo pháp lý",
    "Privacy policy link" : "Liên kết Chính sách riêng tư",
    "Header logo" : "Logo đầu trang",
    "Upload new header logo" : "Tải lên logo đầu trang mới",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Tải lên bộ Favicon mới",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Cài đặt phần mở rộng PHP Imagemagick với hỗ trợ cho hình ảnh SVG để tự động tạo bộ favicon dựa trên màu và logo được tải lên"
},
"nplurals=1; plural=0;");

==> nextcloud-22.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/vi.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Đang tải mục xem trước...",
    "Saved" : "Đã lưu",
    "Admin" : "Quản trị viên",
    "a safe home for all your data" : "một ngôi nhà an toàn cho tất cả dữ liệu của bạn",
    "Name cannot be empty" : "Tên không thể trống",
    "The given name is too long" : "Tên quá dài",
    "The given web address is too long" : "Địa chỉ web quá dài",
    "The given web address is not a valid URL" : "Địa chỉ web được cấp không phải là một đường dân URL khả dụng",
    "The given legal notice address is too long" : "Địa chỉ thông cáo pháp lý được cấp quá dài",
    "The given legal notice address is not a valid URL" : "Địa chỉ thông cáo pháp lý được cấp không phải là một đường dẫn URL khả dụng",
    "The given privacy policy address is too long" : "Địa chỉ chính sách riêng tư quá dài",
    "The given privacy policy address is not a valid URL" : "Địa chỉ chính sách riêng tư được cấp không phải là một đường dẫn URL khả dụng",
    "The given slogan is too long" : "Khẩu hiệu quá dài",
    "The given color is invalid" : "Màu không hợp lệ",
    "The file was uploaded" : "Tập tin đã được tải lên",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tập tin tải lên đã vượt quá upload_max_filesize giới hạn trong hệ thống",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tập được tải lên vượt quá MAX_FILE_SIZE đã được giới hạn trong biểu mẫu HTML",
    "The file was only partially uploaded" : "Tệp chỉ được tải lên một phần",
    "No file was uploaded" : "Chưa có tệp nào dược tải lên",
    "Missing a temporary folder" : "Thiếu một thư mục tạm thời",
    "Could not write file to disk" : "Không thể ghi tệp lên ổ đĩa",
    "A PHP extension stopped the file upload" : "Một phần mở rộng của PHP đã dừng tải tệp lên",
    "No file uploaded" : "Không có tệp nào được tải lên",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Bạn đang sử dụng 1 chủ đề riêng. Các thiết lập của ứng dụng Chủ đề có thể bị ghi đè bởi nó.",
    "Theming" : "Điều chỉnh giao diện",
    "Legal notice" : "Thông cáo pháp lý",
    "Privacy policy" : "Chính sách riêng tư",
    "Adjust the Nextcloud theme" : "Tinh chỉnh chủ đề Nextcloud",
    "Open documentation" : "Mở tài liệu",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Điều chỉnh giao diện cho phép bạn có thể dễ dàng tùy biến bố cục trình bày của hệ thống. Khi thực hiện nó sẽ hiện hữu đối với tất cả người dùng",
    "Name" : "Tên",
    "Reset to default" : "Đặt lại về mặc định",
    "Web link" : "Liên kết web",
    "https://…" : "https://…",
    "Slogan" : "Khẩu hiệu",
    "Color" : "Màu sắc",
    "Logo" : "Logo",
    "Upload new logo" : "Tải lên logo mới",
    "Login image" : "Hình ảnh trang đăng nhập",
    "Upload new login background" : "Tải lên ảnh nền trang đăng nhập mới",
    "Remove background image" : "Xóa bỏ ảnh nền",
    "Advanced options" : "Tùy chọn nâng cao",
    "Legal notice link" : "Liên kết Thông cáo pháp lý",
    "Privacy policy link" : "Liên kết Chính sách riêng tư",
    "Header logo" : "Logo đầu trang",
    "Upload new header logo" : "Tải lên logo đầu trang mới",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Tải lên bộ Favicon mới",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Cài đặt phần mở rộng PHP Imagemagick với hỗ trợ cho hình ảnh SVG để tự động tạo bộ favicon dựa trên màu và logo được tải lên"
},
"nplurals=1; plural=0;");
